<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>PreviousWindow</name>
    <message>
        <location filename="../PreviousWindowInit.js" line="+2"/>
        <source>&amp;Previous</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Poprze&amp;dni widok
Znajdź &amp;poprzednie</translatorcomment>
        <translation>&amp;Poprzednie</translation>
    </message>
</context>
</TS>
